/*
 * Created on 14-jul-2005
 *
 * gvSIG. Sistema de Informacin Geogrfica de la Generalitat Valenciana
 *
 * Copyright (C) 2004 IVER T.I. and Generalitat Valenciana.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307,USA.
 *
 * For more information, contact:
 *
 *  Generalitat Valenciana
 *   Conselleria d'Infraestructures i Transport
 *   Av. Blasco Ibez, 50
 *   46010 VALENCIA
 *   SPAIN
 *
 *      +34 963862235
 *   gvsig@gva.es
 *      www.gvsig.gva.es
 *
 *    or
 *
 *   IVER T.I. S.A
 *   Salamanca 50
 *   46005 Valencia
 *   Spain
 *
 *   +34 963163400
 *   dac@iver.es
 */
package com.iver.gvsig.geoprocessing.gui.operationpanels;

import java.awt.Component;
import java.io.File;

import javax.swing.DefaultComboBoxModel;
import javax.swing.JFileChooser;
import javax.swing.JPanel;
import javax.swing.JLabel;
import javax.swing.JComboBox;
import javax.swing.JCheckBox;
import javax.swing.JList;
import javax.swing.JScrollBar;
import javax.swing.JScrollPane;
import javax.swing.JTextField;
import javax.swing.JButton;

import com.hardcode.gdbms.engine.data.DataSource;
import com.iver.andami.PluginServices;
import com.iver.cit.gvsig.fmap.DriverException;
import com.iver.cit.gvsig.fmap.layers.FBitSet;
import com.iver.cit.gvsig.fmap.layers.FLayers;
import com.iver.cit.gvsig.fmap.layers.layerOperations.AlphanumericData;
import com.iver.cit.gvsig.fmap.layers.layerOperations.Selectable;
import com.iver.utiles.GenericFileFilter;

public class GeoProcessingDissolvePanel extends JPanel {

    /**
     * 
     */
    private static final long serialVersionUID = 1L;
    private JLabel titleJLabel = null;
    private JLabel inputCoverJLabel = null;
    private JComboBox inputCoverJComboBox = null;
    private JCheckBox onlySelectedItemsJCheckBox = null;
    private JLabel dissolveFieldJLabel = null;
    private JComboBox dissolveFieldJComboBox = null;
    private JLabel additionalOperationsJLabel = null;
    private JScrollPane additionalOperationsJScrollPane = null;
    private JList additionalOperationsJList = null;
    private JLabel outputCoverJLabel = null;
    private JTextField outputCoverJTextField = null;
    private JButton outputCoverJButton = null;
    private FLayers layers = null;
    private File outputFile = null;
    /**
     * This is the default constructor
     */
    /*public GeoProcessingDissolvePanel() {
        super();
        initialize();
    }*/

    /**
     * This constructor initializes the set of layers
     */
    public GeoProcessingDissolvePanel(FLayers layers) {
        super();
        this.layers = layers;
        initialize();
    }

    /**
     * This method initializes this
     * 
     * @return void
     */
    private void initialize() {
        outputCoverJLabel = new JLabel();
        outputCoverJLabel.setBounds(5, 206, 111, 22);
        outputCoverJLabel.setText(PluginServices.getText(this,"Cobertura_de_salida") + ":");
        additionalOperationsJLabel = new JLabel();
        additionalOperationsJLabel.setBounds(5, 126, 134, 22);
        additionalOperationsJLabel.setEnabled(false);
        additionalOperationsJLabel.setText(PluginServices.getText(this,"Operaciones_adicionales") + ":");
        dissolveFieldJLabel = new JLabel();
        dissolveFieldJLabel.setBounds(5, 94, 121, 22);
        dissolveFieldJLabel.setText(PluginServices.getText(this,"Campo_para_disolver") + ":");
        inputCoverJLabel = new JLabel();
        inputCoverJLabel.setBounds(5, 36, 121, 22);
        inputCoverJLabel.setText(PluginServices.getText(this,"Cobertura_de_entrada") + ":");
        titleJLabel = new JLabel();
        titleJLabel.setBounds(5, 5, 185, 22);
        titleJLabel.setText(PluginServices.getText(this,"Disolver._Introduccion_de_datos") + ":");
        this.setLayout(null);
        this.setSize(391, 235);
        this.add(titleJLabel, null);
        this.add(inputCoverJLabel, null);
        this.add(getInputCoverJComboBox(), null);
        this.add(getOnlySelectedItemsJCheckBox(), null);
        this.add(dissolveFieldJLabel, null);
        this.add(getDissolveFieldJComboBox(), null);
        this.add(additionalOperationsJLabel, null);
        this.add(getAdditionalOperationsJScrollPane(), null);
        this.add(outputCoverJLabel, null);
        this.add(getOutputCoverJTextField(), null);
        this.add(getOutputCoverJButton(), null);
        inputCoverJComboBox.setSelectedIndex(0);
        initSelectedItemsJCheckBox();
    }
    private String[] getLayerNames() {
        String[] layerNames = new String[layers.getLayersCount()];
        for (int i=0;i<layers.getLayersCount();i++) {
            layerNames[i] = layers.getLayer(i).getName();
        }
        return layerNames;
    }
    private String[] getFieldNames() {
        AlphanumericData lyr = (AlphanumericData)(layers.getLayer((String)inputCoverJComboBox.getSelectedItem()));
        DataSource ds;
        String[] fieldNames = null;
        try {
            ds = lyr.getRecordset();
            fieldNames = new String[ds.getFieldCount()];
            for (int i = 0; i < ds.getFieldCount(); i++) {
                fieldNames[i] = ds.getFieldName(i);
            }
        } catch (DriverException e) {
            // TODO Auto-generated catch block
            e.printStackTrace();
        } catch (com.hardcode.gdbms.engine.data.driver.DriverException e) {
            // TODO Auto-generated catch block
            e.printStackTrace();
        }
        return fieldNames;
    }
    private void initSelectedItemsJCheckBox() {
        Selectable inputSelectable = (Selectable)(layers.getLayer((String)inputCoverJComboBox.getSelectedItem()));
        FBitSet fBitSet = inputSelectable.getSelection();
        if (fBitSet.cardinality()==0) {
            onlySelectedItemsJCheckBox.setEnabled(false);
        } else {
            onlySelectedItemsJCheckBox.setEnabled(true);
        }
        onlySelectedItemsJCheckBox.setSelected(false);
    }
    /**
     * This method initializes inputCoverJComboBox	
     * 	
     * @return javax.swing.JComboBox	
     */    
    private JComboBox getInputCoverJComboBox() {
    	if (inputCoverJComboBox == null) {
    		inputCoverJComboBox = new JComboBox();
            DefaultComboBoxModel defaultModel = new DefaultComboBoxModel(getLayerNames());
            inputCoverJComboBox.setModel(defaultModel);
    		inputCoverJComboBox.setBounds(144, 36, 241, 22);
            inputCoverJComboBox.addItemListener(new java.awt.event.ItemListener() { 
                public void itemStateChanged(java.awt.event.ItemEvent e) {    
                    System.out.println("itemStateChanged()"); // TODO Auto-generated Event stub itemStateChanged()
                    // Cambiar el estado del CheckBox
                    initSelectedItemsJCheckBox();
                    // Cambiar el estado del jComboBox1
                    DefaultComboBoxModel defaultModel = new DefaultComboBoxModel(getFieldNames());
                    dissolveFieldJComboBox.setModel(defaultModel);
                }
            });
    	}
    	return inputCoverJComboBox;
    }

    /**
     * This method initializes onlySelectedItemsJCheckBox	
     * 	
     * @return javax.swing.JCheckBox	
     */    
    private JCheckBox getOnlySelectedItemsJCheckBox() {
    	if (onlySelectedItemsJCheckBox == null) {
    		onlySelectedItemsJCheckBox = new JCheckBox();
    		onlySelectedItemsJCheckBox.setBounds(5, 64, 266, 22);
    		onlySelectedItemsJCheckBox.setText(PluginServices.getText(this,"Usar_solamente_los_elementos_seleccionados"));
    	}
    	return onlySelectedItemsJCheckBox;
    }

    /**
     * This method initializes dissolveFieldJComboBox	
     * 	
     * @return javax.swing.JComboBox	
     */    
    private JComboBox getDissolveFieldJComboBox() {
    	if (dissolveFieldJComboBox == null) {
    		dissolveFieldJComboBox = new JComboBox();
            DefaultComboBoxModel defaultModel = new DefaultComboBoxModel(getFieldNames());
            dissolveFieldJComboBox.setModel(defaultModel);
    		dissolveFieldJComboBox.setBounds(144, 94, 241, 22);
    	}
    	return dissolveFieldJComboBox;
    }

    /**
     * This method initializes additionalOperationsJScrollPane	
     * 	
     * @return javax.swing.JScrollPane	
     */    
    private JScrollPane getAdditionalOperationsJScrollPane() {
    	if (additionalOperationsJScrollPane == null) {
    		additionalOperationsJScrollPane = new JScrollPane();
    		additionalOperationsJScrollPane.setBounds(144, 126, 241, 69);
    		additionalOperationsJScrollPane.setEnabled(false);
    		additionalOperationsJScrollPane.setViewportView(getAdditionalOperationsJList());
    	}
    	return additionalOperationsJScrollPane;
    }

    /**
     * This method initializes additionalOperationsJList	
     * 	
     * @return javax.swing.JList	
     */    
    private JList getAdditionalOperationsJList() {
    	if (additionalOperationsJList == null) {
    		additionalOperationsJList = new JList();
    	}
    	return additionalOperationsJList;
    }

    /**
     * This method initializes outputCoverJTextField	
     * 	
     * @return javax.swing.JTextField	
     */    
    private JTextField getOutputCoverJTextField() {
    	if (outputCoverJTextField == null) {
    		outputCoverJTextField = new JTextField();
    		outputCoverJTextField.setBounds(124, 206, 197, 22);
    	}
    	return outputCoverJTextField;
    }

    /**
     * This method initializes outputCoverJButton	
     * 	
     * @return javax.swing.JButton	
     */    
    private JButton getOutputCoverJButton() {
    	if (outputCoverJButton == null) {
    		outputCoverJButton = new JButton();
    		outputCoverJButton.setBounds(326, 206, 60, 22);
    		outputCoverJButton.addActionListener(new java.awt.event.ActionListener() { 
    			public void actionPerformed(java.awt.event.ActionEvent e) {    
    				System.out.println("actionPerformed()"); // TODO Auto-generated Event stub actionPerformed()
                    JFileChooser jfc = new JFileChooser();
                    jfc.addChoosableFileFilter(new GenericFileFilter("shp", "Ficheros SHP"));
                    if (jfc.showSaveDialog((Component) PluginServices.getMainFrame()) == JFileChooser.APPROVE_OPTION) {
                        File file = jfc.getSelectedFile();
                        if (!(file.getPath().endsWith(".shp") || file.getPath().endsWith(".SHP"))){
                            file = new File(file.getPath()+".shp");
                        }
                        outputFile = file;
                    }
                    if (jfc.getSelectedFile()!=null) getOutputCoverJTextField().setText(jfc.getSelectedFile().getAbsolutePath());
    			}
    		});
    		outputCoverJButton.setText(PluginServices.getText(this,"Abrir"));
    	}
    	return outputCoverJButton;
    }

    /**
     * @return Returns the outputFile.
     */
    public File getOutputFile() {
        return outputFile;
    }

}  //  @jve:decl-index=0:visual-constraint="9,10"
